@@ -12,7 +12,7 @@ test_that("load_and_save_videos",{
         
             ff <- tempfile(fileext=".mp4")
             save.video(im,ff)
-            expect(file_test("-f",ff),TRUE)
+            expect_true(file_test("-f",ff))
             im2 <- load.video(ff)
             unlink(ff)
             expect_equal(im,im2)
